@@ -13,5 +13,6 @@ enum
 	ID_MenuFileNew,
 	ID_MenuFileEdit,
 	ID_MenuFileSave,
-	ID_MenuFileRemove
+	ID_MenuFileRemove,
+	ID_MenuFileHighlight
 };
