@@ -99,7 +99,7 @@ WikiList* mnModel::search(const char* searchStr)
 			for(i = 0; tokenList[i] != NULL; i++){
 				toLower(tokenList[i]);
 				if(strstr((const char*)buf, (const char*)tokenList[i]) ||
-					strstr((const char*)decodeFileName, (const char*)tokenList[i])) {
+					strstr((const char*)decodeFileNameBuf, (const char*)tokenList[i])) {
 					found = TRUE;
 				}
 				else {
